/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.service;

import com.alicp.jetcache.anno.CacheType;
import com.alicp.jetcache.anno.CacheUpdate;
import com.alicp.jetcache.anno.Cached;
import com.zayac.admin.constant.ApiPathConstants;
import com.zayac.admin.resp.Banner;
import com.zayac.admin.system.model.resp.AccountResp;
import lombok.RequiredArgsConstructor;
import org.springframework.core.ParameterizedTypeReference;
import org.springframework.stereotype.Service;

import java.util.concurrent.CompletableFuture;

@Service
@RequiredArgsConstructor
public class BannerService {
    private final CompletableFutureWebClientService completableFutureWebClientService;

    public CompletableFuture<Banner> getLatestBannerInfoAsync(AccountResp account) {
        // Fetch banner data using a WebClient service
        return completableFutureWebClientService
            .fetchDataForAccount(account, ApiPathConstants.BANNER_URL, null, new ParameterizedTypeReference<>() {
            });
    }

    @Cached(name = "bannerCache", key = "#account.id", expire = 90, cacheType = CacheType.BOTH, syncLocal = true)
    public Banner getPreviousBanner(AccountResp account) {
        // 这个方法不需要实际的加载逻辑，因为它只是返回缓存中的数据
        return null;
    }

    @CacheUpdate(name = "bannerCache", key = "#account.id", value = "#banner")
    public void updateBanner(AccountResp account, Banner banner) {
        // Method intentionally left empty, used only for cache update
    }
}
