/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.system.service.impl;

import cn.hutool.core.collection.CollUtil;
import com.zayac.admin.common.model.resp.LabelValueResp;
import lombok.RequiredArgsConstructor;

import org.springframework.stereotype.Service;

import top.continew.starter.extension.crud.service.impl.BaseServiceImpl;
import com.zayac.admin.system.mapper.PlatformMapper;
import com.zayac.admin.system.model.entity.PlatformDO;
import com.zayac.admin.system.model.query.PlatformQuery;
import com.zayac.admin.system.model.req.PlatformReq;
import com.zayac.admin.system.model.resp.PlatformDetailResp;
import com.zayac.admin.system.model.resp.PlatformResp;
import com.zayac.admin.system.service.PlatformService;

import java.util.ArrayList;
import java.util.List;

/**
 * 平台业务实现
 *
 * @author zayac
 * @since 2024/05/14 12:28
 */
@Service
@RequiredArgsConstructor
public class PlatformServiceImpl extends BaseServiceImpl<PlatformMapper, PlatformDO, PlatformResp, PlatformDetailResp, PlatformQuery, PlatformReq> implements PlatformService {
    @Override
    public PlatformDO getByName(String name) {
        return baseMapper.selectByName(name);
    }

    @Override
    public PlatformDO getByPlatformId(Integer platformId) {
        return baseMapper.selectByPlatformId(platformId);
    }

    @Override
    public List<LabelValueResp<Long>> buildDict(List<PlatformResp> list) {
        if (CollUtil.isEmpty(list)) {
            return new ArrayList<>(0);
        }
        return list.stream().map(r -> new LabelValueResp<>(r.getName(), r.getId())).toList();
    }
}